..
    :copyright: Copyright (c) 2013 Martin Pengelly-Phillips
    :license: See LICENSE.txt.

.. _api_reference:

*************
API Reference
*************

clique
======

.. automodule:: clique

.. toctree::
    :maxdepth: 1
    :glob:

    *
